%   Inputs
%       N:    number of atoms in the simulation
%       Tdes: desired system temperature (100K recommended)
%   
%   Constants:
%       dt:   timestep size (10 femtoseconds recommended)
%       amass: atomic mass (6.634e-26 kg/atom for argon)
%       sigma: atomic diameter (.3405e-9m for argon)
%       kb: Boltzmann's constant (1.380e-23 J/K*molecule)
%       epsilon: LJ potential (kb*119.8K)
%           so epsilon's units are J/molecule
%
dt = 1.e-14;
dtq2 = dt/2;
dtsq = dt^2;
dtsq2 = dtsq/2;
amass = 6.634e-26;
amassinv = 1./amass;
sigma = 0.3405e-9;
sigmainv = 1./sigma;
sigsq = sigma^2;
kb = 1.380e-23;
epsilon = 119.8*kb;
eps24 = 24.*epsilon;
%
% Use global values of positions from previous timesteps
%
%    ??? - Simply uncomment the global command line
%
% global N boxL rx ry rz Vx Vy Vz timelapse axislim
Ninv = 1./N;
bigeyes = 1.e10*eye(N);
qboxL = 1./boxL;
%
% Checking initial positions
%
asize = 100.0; % in points... therefore not actual dimensions
rxplot = sigmainv*rx;
ryplot = sigmainv*ry;
rzplot = sigmainv*rz; 
scatter3(rxplot,ryplot,rzplot,asize,'r','filled')
axis manual;
axis([-axislim axislim -axislim axislim -axislim axislim])
axis vis3d;
disp('Atom grid reinitialized... see plot then press any key to continue') 
pause
%
disp('Reinitialized system temperature from velocity comps:')
Tinit = (amass/(3*N*kb))*sum((Vx.*Vx)+(Vy.*Vy)+(Vz.*Vz));
disp(Tinit)
%
Vsq = 0.;
kdtend = input('Enter the desired number of time steps:  ');
for kdt = 1:kdtend
    rxi = repmat(rx,1,N);
    ryi = repmat(ry,1,N);
    rzi = repmat(rz,1,N);
    rxj = rxi';
    ryj = ryi';
    rzj = rzi';
    rxij = rxi - rxj;
    ryij = ryi - ryj;
    rzij = rzi - rzj;
    % correcting of distances for periodic boundaries
    rxij = rxij - boxL*round(qboxL*rxij);
    ryij = ryij - boxL*round(qboxL*ryij);
    rzij = rzij - boxL*round(qboxL*rzij);
    %
    % Force Computations
    %
    rijsq = rxij.*rxij + ryij.*ryij + rzij.*rzij;
    % if (rijsq < rcutsq)
    % Diagonal Correction: 
    % Since i-i forces would compute as infinite, we add a large diagonal 
    % matrix to rijsq to simulate very large distances and therefore zero forces
    rijsq = rijsq + bigeyes;
    rsqinv = 1./rijsq;
    sqr2 = sigsq.*rsqinv;
    sqr6 = sqr2.*sqr2.*sqr2;
    sqr12 = sqr6.*sqr6;
    fqrij = eps24.*rsqinv.*(2.*sqr12 - sqr6);
    fxij = fqrij.*rxij;
    fyij = fqrij.*ryij;
    fzij = fqrij.*rzij;
    fx = sum(fxij,2);
    fy = sum(fyij,2);
    fz = sum(fzij,2);
    ax = amassinv*fx;
    ay = amassinv*fy;
    az = amassinv*fz;
    % 
    %  Modified Verlet Algoritm for computing molecular displacements
    %
    %  ax, ay, az already computed based on rij
    %
    Vx = Vx + dtq2*ax;
    Vy = Vy + dtq2*ay;
    Vz = Vz + dtq2*az;
    rx = rx + dt*Vx + dtsq2*ax;
    ry = ry + dt*Vy + dtsq2*ay;
    rz = rz + dt*Vz + dtsq2*az;
    Vx = Vx + dtq2*ax;
    Vy = Vy + dtq2*ay;
    Vz = Vz + dtq2*az;
    %
    % Correcting of periodic boundary positions after movement is computed
    % 
    %   Periodic boundary logic:
    %       if(rx(i)> boxL/2) rx(i) = rx(i) - boxL; end
    %       if(rx(i)<-boxL/2) rx(i) = rx(i) + boxL; end
    %          and repeated for y and z dimensions
    %
    %   Instead do the following to cut the computation time down:
    %
    rx = rx - boxL*round(qboxL*rx);
    ry = ry - boxL*round(qboxL*ry);
    rz = rz - boxL*round(qboxL*rz);
    %
    %  Gathering average kinetic energies for system temperature checks
    %
    % if kdt >= 76
        Vsq = Vsq + sum(Vx.*Vx + Vy.*Vy + Vz.*Vz);
    % end
end  % End of the do loop for time iterations    
%
%  Updating scatter plot of atoms
%
rxplot = sigmainv*rx;
ryplot = sigmainv*ry;
rzplot = sigmainv*rz; 
scatter3(rxplot,ryplot,rzplot,asize,'b','filled')
axis manual;
axis([-axislim axislim -axislim axislim -axislim axislim])
axis vis3d;
disp('Time loop completed.  Elapsed time (in nanoseconds) is: ')
Timelapse = Timelapse + kdtend*dt*1e9;
disp(Timelapse)
Temp = (amass/(3*N*kb))*(Vsq/kdtend);
disp('Average system temperature during this time loop:')
disp(Temp)
disp('See updated plot then press any key to continue')
pause
disp('Rerun MDcont to continue this simulation')



